==> index.php?dir=services%2Fauspice%2F&file=aus2.6p.tgz: auspices/src/version.sh <==
#!/bin/sh
#
# Increment services build number
if [ -f version.h ] ; then
        BUILD=`fgrep '#define BUILD' version.h | sed 's/^#define BUILD.*"\([0-9]*\)".*$/\1/'`
        BUILD=`expr $BUILD + 1`
else
        BUILD=1
fi
cat >version.h <<EOF
/* Version information for Services.
 *
 * Auspice Services is copyright (c) 2000-2001 In Mean.
 *     E-mail: <auspice@auspice.org>
 *
 * This program is free but copyrighted software; see the file LICENSE for
 * details.
 */

#define BUILD   "$BUILD"

const char version_number[] = "2.6";
const char version_dec[] = "Aggressive";
const char version_build[] =
	"build #" BUILD ", compiled " __DATE__ " " __TIME__
	;

static char *giveinfo[] =
{
    "Based on SirvNET Services writen by By Trevor Klingbeil.",
    "Copyright 2000-2002 The Auspice IRC Network",
    "This program is free software, you can redistribute it and/or",
    "modify it under the terms of the GNU General Public License as",
    "published by the Free Software Foundation; either version 1, or",
    "(at your option) any later version.",
    "The following people have contributed code and suggestions",
    "which have helped to make this program what it is today:",
    " ",
    "\2\37Auspice Services:\37\2",
    "Auspice       In Mean            auspice@auspice.org",
    " ",
    "\2\37SirvNET:\37\2",
    "Priority1     Trevor Klingbeil   Priority1@dal.net",
    " ",
    "\2\37Espernet IRC Services:\37\2",
    "Alcan         Andrew Church      achurch@dragonfire.net",
    " ",
    "Thanks to all those involved that were not mentioned",
    "who have added their advice, opinions, and code to the",
    "development of services.",
    0,
};

static char *givecredit[] =
{
    " ",
    "\2\37Auspice IRC Services\37 CREDIT.\2",
    "-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=",
    "The people on this list is people who have helped up through",
    "the development of Auspice Services. The Auspice Team would like",
    "to thanks those people by listing them here:",
    "-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=",
    "\2\37Teams\2\37",
    " Auspice             Team Leader",
    " ltX                 Check spelling",
    " Khmerboy            Check spelling",
    " Rocko               Check spelling",
    " ",
    "\2\37Special Thanks to\2\37",
    " ",
    "GhostFunky           irc.virtualspeed.org",
    "Esa                  former irc.israel.net admin",
    "Tim                  www.jetdial.net",
    "Dereal and Rowdy     for java.auspice.org",
    "HoneyFlower          for love.com, care.com ;p",
    " ",
    "SourceForge.net",
    " ",
    "\37Auspice.org Team\37",
    "Daviid, RETh, Khmerboy, Yong, GhostFunky",
    "\37These people have helped me beta test and ideas\37",
    "Kim9, Taz, Spirit, GoNis, TraceRout, DarkLotus",
    "Spirit, Bomb, XStart, DarqStlkr, Paradise, Solar",
    "Ben, Neox, Cowboy, Terrence, PFAK, doc, Alen, D_Peti", 
    "JUStice, SiRoCu, NiceGuy, Khmerboy, crash, dvdman",
    " ",
    "\37Peoples in memory\37",
    "*Open http://www.auspice.org and click on Credits",
    " ",
    "Thanks to all those involved that were not mentioned",
    "who have added their advice, opinions, and code to the",
    "development of services.",
    " ",
    "-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=",
    " ",
    0,
};
EOF

==> index.php?dir=services%2Fauspice%2F&file=aus2.8.tgz: auspices/src/version.sh <==
#!/bin/sh
#
# Increment services build number
if [ -f version.h ] ; then
        BUILD=`fgrep '#define BUILD' version.h | sed 's/^#define BUILD.*"\([0-9]*\)".*$/\1/'`
        BUILD=`expr $BUILD + 1`
else
        BUILD=1
fi
cat >version.h <<EOF
/* Version information for Services.
 *
 * Auspice Services is copyright (c) 2000-2001 In Mean.
 *     E-mail: <auspice@auspice.org>
 *
 * This program is free but copyrighted software; see the file LICENSE for
 * details.
 */

#define BUILD   "$BUILD"

const char version_number[] = "2.8";
const char version_dec[] = "Clean";
const char version_build[] =
	"build #" BUILD ", compiled " __DATE__ " " __TIME__
	;

static char *giveinfo[] =
{
    "Based on SirvNET Services writen by By Trevor Klingbeil.",
    "Copyright 2000-2002 The Auspice IRC Network",
    "This program is free software, you can redistribute it and/or",
    "modify it under the terms of the GNU General Public License as",
    "published by the Free Software Foundation; either version 1, or",
    "(at your option) any later version.",
    "The following people have contributed code and suggestions",
    "which have helped to make this program what it is today:",
    " ",
    "\2\37Auspice Services:\37\2",
    "Auspice       In Mean            inmean@inmean.com",
    " ",
    "\2\37SirvNET:\37\2",
    "Priority1     Trevor Klingbeil   Priority1@dal.net",
    " ",
    "\2\37Espernet IRC Services:\37\2",
    "Alcan         Andrew Church      achurch@dragonfire.net",
    " ",
    "Thanks to all those involved that were not mentioned",
    "who have added their advice, opinions, and code to the",
    "development of services.",
    0,
};

static char *givecredit[] =
{
    " ",
    "\2\37Auspice IRC Services\37 CREDIT.\2",
    "-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=",
    "The people on this list is people who have helped up through",
    "the development of Auspice Services. The Auspice Team would like",
    "to thanks those people by listing them here:",
    "-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=",
    "\2\37Teams\2\37",
    " Auspice             Team Leader",
    "\2\37Support Teams\2\37"
    " khmerboy, Rocko",
    " raw, havlaz, xx12, SyberVenom, volta BeckHam07",
    "\2\37Special Thanks to\2\37",
    "Tim -  absoluteshells.com",
    "SourceForge.net For provide space hosting",
    " ",
    "\37These people have helped me beta test and ideas\37",
    "Kim9, Taz, Spirit, GoNis, TraceRout, DarkLotus",
    "Spirit, Bomb, XStart, DarqStlkr, Paradise, Solar",
    "Ben, Neox, Cowboy, Terrence, PFAK, doc, Alen, D_Peti", 
    "JUStice, SiRoCu, NiceGuy, Khmerboy, crash, dvdman, Omega",
    "Fiend, Angel, Zeh, ghostfunky, Esa, Rowdy",
    " ",
    "\37Peoples in memory\37",
    "*Open http://www.inmean.com",
    " ",
    "Thanks to all those involved that were not mentioned",
    "who have added their advice, opinions, and code to the",
    "development of services.",
    " ",
    "-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=",
    " ",
    0,
};
EOF
